| Title: | RStudio Addin to Search and Copy Emoji |
|---|---|
| Description: | RStudio addin to search through emoji and copy the emoji name, unicode string or glyph to the clipboard. |
| Authors: | Garrick Aden-Buie [aut, cre] (ORCID: <https://orcid.org/0000-0002-7111-0077>) |
| Maintainer: | Garrick Aden-Buie <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.0 |
| Built: | 2026-05-16 06:46:03 UTC |
| Source: | https://github.com/gadenbuie/ermoji |
An emoji picker gadget that lets you search and find emoji and insert either
the unicode, HTML, or emo::ji() versions of the emoji. Built using the
Emoji Button JavaScript library.
emoji_picker(gadget = TRUE)emoji_picker(gadget = TRUE)
gadget |
If |
A list with the emoji, the emoji name and the html entity.
Uses emo::ji() to look up emoji, but return the escaped HTML.
emoji2html(x, copy = clipr::clipr_available())emoji2html(x, copy = clipr::clipr_available())
x |
A search term passed to |
copy |
Should the result be copied to the clipboard? |
Opens a miniUI based Shiny gadget in the RStudio Viewer pane with a searchable table of emoji. Select a row and click the copy desired button.
ermoji_gadget(clipout = clipr::clipr_available(), ...) ermoji_shiny(clipout = clipr::clipr_available(), ...)ermoji_gadget(clipout = clipr::clipr_available(), ...) ermoji_shiny(clipout = clipr::clipr_available(), ...)
clipout |
Should the gadget attempt to write to the clipboard? |
... |
Ignored at this time |
nothing